@@ -794,12 +794,8 @@ void
 gdl_dock_item_grip_hide_handle (GdlDockItemGrip *grip)
 {
     g_return_if_fail (grip != NULL);
-    if (grip->priv->handle_shown) {
-        grip->priv->handle_shown = FALSE;
-        gdl_dock_item_grip_showhide_handle (grip);
-        if (grip->priv->title_window != NULL)
-            gdk_window_set_cursor (grip->priv->title_window, NULL);
-    };
+    grip->priv->handle_shown = FALSE;
+    gtk_widget_hide (GTK_WIDGET (grip));
 }
 
 /**
@@ -814,12 +810,7 @@ gdl_dock_item_grip_show_handle (GdlDockItemGrip *grip)
     g_return_if_fail (grip != NULL);
     if (!grip->priv->handle_shown) {
         grip->priv->handle_shown = TRUE;
-        gdl_dock_item_grip_showhide_handle (grip);
-        if (grip->priv->title_window != NULL) {
-            GdkCursor *cursor = gdk_cursor_new_for_display (gtk_widget_get_display (GTK_WIDGET (grip)), GDK_HAND2);
-            gdk_window_set_cursor (grip->priv->title_window, cursor);
-            g_object_unref (cursor);
-        }
+        gtk_widget_show (GTK_WIDGET (grip));
     };
 }
 
